Contributing
------------

Please contribute!  You can contribute by making a pull request or reporting
bugs.  You can also submit feature requests or ask questions about how to do
things with wifi.

How to Submit an Issue
======================

Issues include bug reports, feature requests, documentation requests, and lots
of other things too.

1.  Go to https://github.com/rockymeza/wifi/issues to see the issue tracker.

2.  Please make sure that the issue hasn't already been opened by somebody
    else.

3.  Create a New Issue.  If it is a bug, please tell me what distro you are
    using.  I don't have the capacity to test against a bunch of distros, but I
    do want wifi to work on more than just the one that I use.

How to Submit a Pull Request
============================

1.  Clone the repo.

2.  Run the tests. ::

       $ python setup.py test

3.  Create a topic branch.

4.  Make your awesome changes.

    Don't forget to add tests to make sure that your awesome changes will
    continue to work for all of eternity.

5.  Make sure that your code conforms to PEP8 and the Zen of Python as much as
    possible (ignore E501, the line lengths requirement).

6.  Get on GitHub and submit a pull request.
    
The best pull requests will not have PEP8 errors and will include tests.  If
you don't have tests, I am still willing to accept the pull request, but it may
take a while for me to merge it as I would want to write the tests myself and I
don't have a ton of time I can devote to that (especially during the school
year).
